# CMX front-end for the legacy MLPerf automations

[![License](https://img.shields.io/badge/License-Apache%202.0-green)](LICENSE.md)
[![CMX repository](https://img.shields.io/badge/Common%20Metadata%20eXchange-compatible-blue)](https://github.com/mlcommons/ck/tree/master/cm)
[![Powered by CMX](https://img.shields.io/badge/Powered_by-MLCommons%20CMX-blue)](https://pypi.org/project/cmind).

## License

[Apache 2.0](LICENSE.md)

## Copyright

© 2022-2025 MLCommons. All Rights Reserved.

Grigori Fursin, the cTuning foundation and OctoML donated this project to MLCommons 
to benefit everyone and encourage collaborative development.

## Author

[Grigori Fursin](https://cKnowledge.org/gfursin)

We sincerely appreciate all [contributors](https://github.com/mlcommons/ck/blob/master/CONTRIBUTORS.md) 
for their invaluable feedback and support!

## Parent project

Visit the [parent Collective Knowledge project](https://github.com/mlcommons/ck) for further details.

## Citing this project

If you found the CM, CMX and MLPerf automations helpful, kindly reference this article:
[ [ArXiv](https://arxiv.org/abs/2406.16791) ]
